==> simplenotewidget_0.3-09.tar.gz: simplenotewidget-0.3/src/simplenotewidget_de_DE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>Dialog</name>
    <message>
        <location filename="dialog.ui" line="43"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="dialog.ui" line="56"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="dialog.ui" line="69"/>
        <source>Clear</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="dialog.cpp" line="32"/>
        <source>Edit note</source>
        <translation>Notiz bearbeiten</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>MainWindow</source>
        <translation>MainWindow</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="40"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="53"/>
        <source>cc</source>
        <translation>cc</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="173"/>
        <source>please press twice for the edit mode</source>
        <translation>Bitte doppelklicken um eine Notiz zu schreiben</translation>
    </message>
</context>
<context>
    <name>QtColorComboBox</name>
    <message>
        <location filename="qtcolorcombobox.cpp" line="131"/>
        <source>More...</source>
        <translation>Mehr...</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="232"/>
        <source>User color %1</source>
        <translation>Benutzerfarbe %1</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="276"/>
        <source>User Color 99</source>
        <translation>Benutzerfarbe 99</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="290"/>
        <source>Black</source>
        <translation>Schwarz</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="291"/>
        <source>White</source>
        <translation>Weiss</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="292"/>
        <source>Red</source>
        <translation>Rot</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="293"/>
        <source>Dark red</source>
        <translation>Dunkelrot</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="294"/>
        <source>Green</source>
        <translation>Grün</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="295"/>
        <source>Dark green</source>
        <translation>Dunkelgrün</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="296"/>
        <source>Blue</source>
        <translation>Blau</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="297"/>
        <source>Dark blue</source>
        <translation>Dunkelblau</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="298"/>
        <source>Cyan</source>
        <translation>Cyan</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="299"/>
        <source>Dark cyan</source>
        <translation>Dunkelcyan</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="300"/>
        <source>Magenta</source>
        <translation>MAgenta</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="301"/>
        <source>Dark magenta</source>
        <translation>Dunkelmagenta</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="302"/>
        <source>Yellow</source>
        <translation>Gelb</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="303"/>
        <source>Dark yellow</source>
        <translation>Dunkelgelb</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="304"/>
        <source>Gray</source>
        <translation>Grau</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="305"/>
        <source>Dark gray</source>
        <translation>Dunkelgrau</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="306"/>
        <source>Light gray</source>
        <translation>Hellgrau</translation>
    </message>
</context>
<context>
    <name>SettingsWidget</name>
    <message>
        <location filename="settingswidget.ui" line="14"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <location filename="settingswidget.ui" line="26"/>
        <source>Transparency:</source>
        <translation>Transparenz:</translation>
    </message>
    <message>
        <location filename="settingswidget.ui" line="39"/>
        <source>Text color:</source>
        <translation>Textfarbe:</translation>
    </message>
    <message>
        <location filename="settingswidget.ui" line="52"/>
        <source>Background color:</source>
        <translation>Hintergrundfarbe:</translation>
    </message>
    <message>
        <location filename="settingswidget.ui" line="95"/>
        <source>Font-Family:</source>
        <translation>Schriftart:</translation>
    </message>
    <message>
        <location filename="settingswidget.ui" line="108"/>
        <source>Font-Size:</source>
        <translation>Schriftfarbe:</translation>
    </message>
    <message>
        <location filename="settingswidget.ui" line="121"/>
        <source>Use System Colors:</source>
        <translation>Systemfarben:</translation>
    </message>
</context>
<context>
    <name>settingsdlg</name>
    <message>
        <location filename="settingsdlg.cpp" line="16"/>
        <source>Edit settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="settingsdlg.ui" line="26"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="settingsdlg.ui" line="39"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
</TS>

==> simplenotewidget_0.3-10.tar.gz: simplenotewidget-0.3/src/simplenotewidget_de_DE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>Dialog</name>
    <message>
        <location filename="dialog.ui" line="43"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="dialog.ui" line="56"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="dialog.ui" line="69"/>
        <source>Clear</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="dialog.cpp" line="32"/>
        <source>Edit note</source>
        <translation>Notiz bearbeiten</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>MainWindow</source>
        <translation>MainWindow</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="40"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="53"/>
        <source>cc</source>
        <translation>cc</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="176"/>
        <source>please press twice for the edit mode</source>
        <translation>Bitte doppelklicken um eine Notiz zu schreiben</translation>
    </message>
</context>
<context>
    <name>QtColorComboBox</name>
    <message>
        <location filename="qtcolorcombobox.cpp" line="131"/>
        <source>More...</source>
        <translation>Mehr...</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="232"/>
        <source>User color %1</source>
        <translation>Benutzerfarbe %1</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="276"/>
        <source>User Color 99</source>
        <translation>Benutzerfarbe 99</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="290"/>
        <source>Black</source>
        <translation>Schwarz</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="291"/>
        <source>White</source>
        <translation>Weiss</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="292"/>
        <source>Red</source>
        <translation>Rot</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="293"/>
        <source>Dark red</source>
        <translation>Dunkelrot</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="294"/>
        <source>Green</source>
        <translation>Grün</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="295"/>
        <source>Dark green</source>
        <translation>Dunkelgrün</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="296"/>
        <source>Blue</source>
        <translation>Blau</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="297"/>
        <source>Dark blue</source>
        <translation>Dunkelblau</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="298"/>
        <source>Cyan</source>
        <translation>Cyan</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="299"/>
        <source>Dark cyan</source>
        <translation>Dunkelcyan</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="300"/>
        <source>Magenta</source>
        <translation>MAgenta</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="301"/>
        <source>Dark magenta</source>
        <translation>Dunkelmagenta</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="302"/>
        <source>Yellow</source>
        <translation>Gelb</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="303"/>
        <source>Dark yellow</source>
        <translation>Dunkelgelb</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="304"/>
        <source>Gray</source>
        <translation>Grau</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="305"/>
        <source>Dark gray</source>
        <translation>Dunkelgrau</translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="306"/>
        <source>Light gray</source>
        <translation>Hellgrau</translation>
    </message>
</context>
<context>
    <name>SettingsWidget</name>
    <message>
        <location filename="settingswidget.ui" line="14"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <location filename="settingswidget.ui" line="26"/>
        <source>Transparency:</source>
        <translation>Transparenz:</translation>
    </message>
    <message>
        <location filename="settingswidget.ui" line="39"/>
        <source>Text color:</source>
        <translation>Textfarbe:</translation>
    </message>
    <message>
        <location filename="settingswidget.ui" line="52"/>
        <source>Background color:</source>
        <translation>Hintergrundfarbe:</translation>
    </message>
    <message>
        <location filename="settingswidget.ui" line="95"/>
        <source>Font-Family:</source>
        <translation>Schriftart:</translation>
    </message>
    <message>
        <location filename="settingswidget.ui" line="108"/>
        <source>Font-Size:</source>
        <translation>Schriftfarbe:</translation>
    </message>
    <message>
        <location filename="settingswidget.ui" line="121"/>
        <source>Use System Colors:</source>
        <translation>Systemfarben:</translation>
    </message>
    <message>
        <location filename="settingswidget.ui" line="147"/>
        <source>Language:</source>
        <translation>Sprache:</translation>
    </message>
    <message>
        <location filename="settingswidget.cpp" line="64"/>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <location filename="settingswidget.cpp" line="172"/>
        <source>Language changed</source>
        <oldsource>Languagechange</oldsource>
        <translation>Sprache gewechselt</translation>
    </message>
    <message>
        <location filename="settingswidget.cpp" line="172"/>
        <source>Changing the language requires a restart of the widget.</source>
        <translation>Das Ändern der Sprache erfordert einen Neustart des Widgets.</translation>
    </message>
    <message>
        <location filename="settingswidget.cpp" line="172"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>settingsdlg</name>
    <message>
        <location filename="settingsdlg.cpp" line="16"/>
        <source>Edit settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="settingsdlg.ui" line="26"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="settingsdlg.ui" line="39"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
</TS>
